@@ -92,7 +92,7 @@ uint ScreenshotPortal::Screenshot(const QDBusObjectPath &handle,
     Utils::setParentWindow(screenshotDialog->windowHandle(), parent_window);
     Request::makeClosableDialogRequest(handle, screenshotDialog.data());
 
-    const bool modal = options.value(QStringLiteral("modal"), false).toBool();
+    const bool modal = options.value(QStringLiteral("modal"), true).toBool();
     screenshotDialog->windowHandle()->setModality(modal ? Qt::WindowModal : Qt::NonModal);
 
     const bool interactive = options.value(QStringLiteral("interactive"), false).toBool();
